aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/glk.h
diff options
context:
space:
mode:
authorPaul Gilbert2019-06-16 13:29:15 -0700
committerPaul Gilbert2019-06-16 14:59:26 -0700
commit553bb74f8c380ee31fb771c6619dad8e83fed8ce (patch)
treebf99be6554e96d66d2700837d7c08dc0d48ad127 /engines/glk/glk.h
parent3876fb67108284063b4d133cf087a04dae6993e4 (diff)
downloadscummvm-rg350-553bb74f8c380ee31fb771c6619dad8e83fed8ce.tar.gz
scummvm-rg350-553bb74f8c380ee31fb771c6619dad8e83fed8ce.tar.bz2
scummvm-rg350-553bb74f8c380ee31fb771c6619dad8e83fed8ce.zip
GLK: Further changeover of sub-engines to use new savegame code
Diffstat (limited to 'engines/glk/glk.h')
-rw-r--r--engines/glk/glk.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/engines/glk/glk.h b/engines/glk/glk.h
index f96f384027..739f1774d9 100644
--- a/engines/glk/glk.h
+++ b/engines/glk/glk.h
@@ -198,14 +198,15 @@ public:
virtual Common::Error saveGameState(int slot, const Common::String &desc) override;
/**
* Load a savegame from the passed file
*/
- virtual Common::Error loadGameData(strid_t file) = 0;
+ virtual Common::Error readSaveData(Common::SeekableReadStream *rs) = 0;
/**
- * Save the game to the passed file
+ * Save the game. The passed write stream represents access to the UMem chunk
+ * in the Quetzal save file that will be created
*/
- virtual Common::Error saveGameData(strid_t file, const Common::String &desc) = 0;
+ virtual Common::Error writeGameData(Common::WriteStream *ws) = 0;
/**
* Generate a beep
@@ -198,14 +198,15 @@ public:
virtual Common::Error saveGameState(int slot, const Common::String &desc) override;
/**
- * Load a savegame from the passed file
+ * Load a savegame from the passed Quetzal file chunk stream
*/